@@ -326,9 +326,10 @@ initable_iface_init (gpointer g_iface,
 const static gchar *valid_queries[] = { "feed",
                                         "own",
                                         "friends-only",
-                                        "x-flickr-search" };
+                                        "x-flickr-search",
+                                        NULL };
 
-static const gchar *valid_contact_queries[] = { "people" };
+static const gchar *valid_contact_queries[] = { "people", NULL };
 
 
 static gboolean
@@ -336,7 +337,7 @@ _check_query_validity (const gchar *query, const gchar *list[])
 {
   gint i = 0;
 
-  for (i = 0; i < G_N_ELEMENTS (list); i++)
+  for (i = 0 ; list[i] != NULL ; i++)
   {
     if (g_str_equal (query, list[i]))
       return TRUE;
@@ -437,11 +438,11 @@ query_iface_init (gpointer g_iface,
 }
 
 static gint
-_flickr_upload (SwServiceFlickr           *self,
-                const gchar               *filename,
-                GHashTable                *params_in,
-                GError                   **error,
-                RestProxyCallAsyncCallback callback)
+_flickr_upload (SwServiceFlickr              *self,
+                const gchar                  *filename,
+                GHashTable                   *params_in,
+                GError                      **error,
+                RestProxyCallUploadCallback   callback)
 {
   SwServiceFlickrPrivate *priv = GET_PRIVATE (self);
   RestProxyCall *call;
@@ -461,17 +462,19 @@ _flickr_upload (SwServiceFlickr           *self,
 
   opid = sw_next_opid ();
 
-  rest_proxy_call_async (call, callback, (GObject *)self,
-                         GINT_TO_POINTER (opid), NULL);
+  rest_proxy_call_upload (call, callback, (GObject *)self,
+                          GINT_TO_POINTER (opid), NULL);
 
   return opid;
 }
 
 static void
 on_photo_upload_cb (RestProxyCall *call,
-              const GError *error,
-              GObject *weak_object,
-              gpointer user_data)
+                    gsize          total,
+                    gsize          uploaded,
+                    const GError  *error,
+                    GObject       *weak_object,
+                    gpointer       user_data)
 {
   SwServiceFlickr *flickr = SW_SERVICE_FLICKR (weak_object);
   int opid = GPOINTER_TO_INT (user_data);
@@ -481,7 +484,9 @@ on_photo_upload_cb (RestProxyCall *call,
     /* TODO: clean up */
   } else {
     /* TODO: check flickr error state */
-    sw_photo_upload_iface_emit_photo_upload_progress (flickr, opid, 100, "");
+    gint percent = (gdouble) uploaded / (gdouble) total * 100;
+    sw_photo_upload_iface_emit_photo_upload_progress (flickr, opid,
+                                                      percent, "");
   }
 }
 
@@ -516,9 +521,11 @@ photo_upload_iface_init (gpointer g_iface,
 
 static void
 on_video_upload_cb (RestProxyCall *call,
-              const GError *error,
-              GObject *weak_object,
-              gpointer user_data)
+                    gsize          total,
+                    gsize          uploaded,
+                    const GError  *error,
+                    GObject       *weak_object,
+                    gpointer       user_data)
 {
   SwServiceFlickr *flickr = SW_SERVICE_FLICKR (weak_object);
   int opid = GPOINTER_TO_INT (user_data);
@@ -528,7 +535,9 @@ on_video_upload_cb (RestProxyCall *call,
     /* TODO: clean up */
   } else {
     /* TODO: check flickr error state */
-    sw_video_upload_iface_emit_video_upload_progress (flickr, opid, 100, "");
+    gint percent = (gdouble) uploaded / (gdouble) total * 100;
+    sw_video_upload_iface_emit_video_upload_progress (flickr, opid,
+                                                      percent, "");
   }
 }
 
