@@ -411,6 +411,10 @@ make_item (SwLastfmItemView *item_view,
   if (s)
     sw_item_request_image_fetch (item, FALSE, "authoricon", s);
 
+  s = get_image_url (user, "large");
+  if (s)
+    sw_item_request_image_fetch (item, FALSE, "authoricon_large", s);
+
   return item;
 }
 
@@ -583,7 +587,8 @@ _load_from_cache (SwLastfmItemView *item_view)
 
   set = sw_cache_load (sw_item_view_get_service (SW_ITEM_VIEW (item_view)),
                        priv->query,
-                       priv->params);
+                       priv->params,
+                       sw_item_set_new);
 
   if (set)
   {
@@ -661,9 +666,24 @@ _service_capabilities_changed_cb (SwService    *service,
                                   const gchar **caps,
                                   SwItemView   *item_view)
 {
+  SwLastfmItemViewPrivate *priv = GET_PRIVATE ((SwLastfmItemView*) item_view);
+
   if (sw_service_has_cap (caps, CREDENTIALS_VALID))
   {
     lastfm_item_view_refresh (item_view);
+    if (!priv->timeout_id)
+    {
+      priv->timeout_id = g_timeout_add_seconds (UPDATE_TIMEOUT,
+                                                (GSourceFunc)_update_timeout_cb,
+                                                item_view);
+    }
+  } else {
+    if (priv->timeout_id)
+    {
+      g_source_remove (priv->timeout_id);
+      priv->timeout_id = 0;
+    }
+
   }
 }
 
