@@ -546,16 +546,17 @@ static const gchar *valid_queries[] = { "feed",
                                         "friends-only",
                                         "x-twitter-mentions",
                                         "x-twitter-stream",
-                                        "x-twitter-trending-topics"};
+                                        "x-twitter-trending-topics",
+                                        NULL };
 
-static const gchar *valid_contact_queries[] = { "people" };
+static const gchar *valid_contact_queries[] = { "people", NULL };
 
 static gboolean
 _check_query_validity (const gchar *query, const gchar *list[])
 {
   gint i = 0;
 
-  for (i = 0; i < G_N_ELEMENTS(list); i++)
+  for (i = 0 ; list[i] != NULL ; i++)
   {
     if (g_str_equal (query, list[i]))
       return TRUE;
